@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[300]:
+# In[301]:
 
 
 try:
@@ -12,10 +12,10 @@ except:
         pass
 
 
-# In[172]:
+# In[426]:
 
 
-version = '0.73'
+version = '0.74'
 
 import re
 import tempfile
@@ -33,7 +33,7 @@ import time
 
 # # Helper Functions
 
-# In[173]:
+# In[303]:
 
 
 def is_testing():
@@ -43,7 +43,7 @@ def is_testing():
         return False
 
 
-# In[174]:
+# In[304]:
 
 
 def isnotebook():
@@ -54,7 +54,7 @@ def isnotebook():
     return False
 
 
-# In[175]:
+# In[305]:
 
 
 def testPrint(*args):
@@ -64,13 +64,13 @@ def testPrint(*args):
 
 # # Timing
 
-# In[176]:
+# In[306]:
 
 
 timeSinceLastCallDict = {}
 
 
-# In[177]:
+# In[307]:
 
 
 def timeSinceLastCall(name):
@@ -83,7 +83,7 @@ def timeSinceLastCall(name):
     return name + ": " + time_s
 
 
-# In[178]:
+# In[308]:
 
 
 if is_testing():
@@ -92,7 +92,7 @@ if is_testing():
 
 # # Requiremtns
 
-# In[179]:
+# In[309]:
 
 
 requirements = []
@@ -124,7 +124,7 @@ import yaml
 
 # # Strings
 
-# In[180]:
+# In[310]:
 
 
 def sFloat0(f): return "{:0.0f}".format(f)
@@ -154,7 +154,7 @@ if is_testing():
     print(sFloatSci5(1.234567))
 
 
-# In[181]:
+# In[311]:
 
 
 def strUuid4():
@@ -165,14 +165,14 @@ def strUuid4():
     return uuid
 
 
-# In[182]:
+# In[312]:
 
 
 if is_testing():
     print(strUuid4())
 
 
-# In[183]:
+# In[313]:
 
 
 def strRand(n, num=True, upperCase=True, lowerCase=True):
@@ -184,7 +184,7 @@ def strRand(n, num=True, upperCase=True, lowerCase=True):
     return ''.join(random.choice(pool) for _ in range(n))
 
 
-# In[184]:
+# In[314]:
 
 
 if is_testing():
@@ -193,7 +193,7 @@ if is_testing():
     print(strRand(20, upperCase=False, lowerCase=False))
 
 
-# In[185]:
+# In[315]:
 
 
 def strMd5Pickle4(obj):
@@ -203,14 +203,14 @@ def strMd5Pickle4(obj):
     return md5.hexdigest()
 
 
-# In[186]:
+# In[316]:
 
 
 if is_testing():
     print(strMd5Pickle4(['a', 'b']))
 
 
-# In[187]:
+# In[317]:
 
 
 def strMd5String(s):
@@ -219,7 +219,7 @@ def strMd5String(s):
     return md5.hexdigest()
 
 
-# In[188]:
+# In[318]:
 
 
 if is_testing():
@@ -228,7 +228,7 @@ if is_testing():
 
 # # Multiprocess / Thread
 
-# In[299]:
+# In[319]:
 
 
 def mapThread(func, args, n=8):
@@ -253,14 +253,14 @@ if is_testing():
 
 # # Lists
 
-# In[190]:
+# In[320]:
 
 
 def liChunks(l, chunk_size):
     return [l[i:i + chunk_size] for i in range(0, len(l), chunk_size)]
 
 
-# In[191]:
+# In[321]:
 
 
 if is_testing():
@@ -269,7 +269,7 @@ if is_testing():
     print(liChunks(['a', 'b', 'c', 'd', 'e', 'f'], 3))
 
 
-# In[192]:
+# In[322]:
 
 
 def liSplit(a, number_of_splits):
@@ -277,7 +277,7 @@ def liSplit(a, number_of_splits):
     return [a[start:end] for start, end in zip(idxs[:-1], idxs[1:])]
 
 
-# In[193]:
+# In[323]:
 
 
 if is_testing():
@@ -289,7 +289,7 @@ if is_testing():
     print(liSplit(['a', 'b', 'c', 'd', 'e'], 6))
 
 
-# In[194]:
+# In[324]:
 
 
 def liJoin(l):
@@ -299,14 +299,14 @@ def liJoin(l):
     return out
 
 
-# In[195]:
+# In[325]:
 
 
 if is_testing():
     print(liJoin([['a', 'b', 'c'], ['d', 'e', 'f']]))
 
 
-# In[196]:
+# In[326]:
 
 
 def liFlatten(l):
@@ -323,7 +323,7 @@ def liFlatten(l):
         return l
 
 
-# In[197]:
+# In[327]:
 
 
 if is_testing():
@@ -333,7 +333,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[198]:
+# In[328]:
 
 
 regex_cache = {}
@@ -343,35 +343,35 @@ def sListFilter(l, re_include=".*", re_exclude='^\b$'):
     return [e for e in l if regex_cache[re_include].search(e) and not regex_cache[re_exclude].search(e)]
 
 
-# In[199]:
+# In[329]:
 
 
 if is_testing():
     sListFilter(['good x', 'other good x', 'without the letter before y'])
 
 
-# In[200]:
+# In[330]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[201]:
+# In[331]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[202]:
+# In[332]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[203]:
+# In[333]:
 
 
 def lCsv(l, force_oneline=False):
@@ -387,21 +387,21 @@ def lCsv(l, force_oneline=False):
     return ", ".join([str(e) for e in l])
 
 
-# In[204]:
+# In[334]:
 
 
 if is_testing():
     print(lCsv(['a', 'b', 1, 3.14]))
 
 
-# In[205]:
+# In[335]:
 
 
 if is_testing():
     print(lCsv([['a', 'b'], 1, 3.14]))
 
 
-# In[206]:
+# In[336]:
 
 
 if is_testing():
@@ -410,7 +410,7 @@ if is_testing():
 
 # # Text files
 
-# In[207]:
+# In[337]:
 
 
 def txtread(path):
@@ -431,7 +431,7 @@ def txtwrite(path, txt):
             return f.write(txt)
 
 
-# In[208]:
+# In[338]:
 
 
 if is_testing():
@@ -440,21 +440,21 @@ if is_testing():
 
 # # YAML files
 
-# In[209]:
+# In[339]:
 
 
 def yamlwrite(path, obj):
     txtwrite(path, yaml.dump(obj))
 
 
-# In[210]:
+# In[340]:
 
 
 def yamlread(path):
     return yaml.safe_load(txtread(path=path))
 
 
-# In[211]:
+# In[341]:
 
 
 if is_testing():
@@ -467,7 +467,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[212]:
+# In[342]:
 
 
 regex_cache = {}
@@ -479,35 +479,35 @@ def sListFilter(listOfStrings, re_include=".*", re_exclude='^\b$'):
 
 # ### Examples
 
-# In[213]:
+# In[343]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
-# In[214]:
+# In[344]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[215]:
+# In[345]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[216]:
+# In[346]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[217]:
+# In[347]:
 
 
 if is_testing():
@@ -516,7 +516,7 @@ if is_testing():
 
 # # GCP Google Cloud Platform
 
-# In[218]:
+# In[348]:
 
 
 import warnings
@@ -540,7 +540,7 @@ def _gsBlob(path):
     return blob
 
 
-# In[219]:
+# In[349]:
 
 
 def gsGsToHttp(path):
@@ -550,7 +550,7 @@ def gsHttpToGs(path):
     return path.replace("https://storage.cloud.google.com/", "gs://").split("?")[0] # "?" is for possible "?authuser=0"
 
 
-# In[220]:
+# In[350]:
 
 
 def gsLs(path):
@@ -560,7 +560,7 @@ def gsLs(path):
     return ['gs://' + bucket + '/' + blob.name for blob in client.list_blobs(prefix=prefix)]
 
 
-# In[221]:
+# In[351]:
 
 
 def gsExists(path):
@@ -570,7 +570,7 @@ def gsExists(path):
     return client.blob(prefix).exists()
 
 
-# In[222]:
+# In[352]:
 
 
 def gsUploadFile(gsPath, path):
@@ -578,7 +578,7 @@ def gsUploadFile(gsPath, path):
     blob.upload_from_filename(path)
 
 
-# In[223]:
+# In[353]:
 
 
 def gsTxtread(path):
@@ -590,7 +590,7 @@ def gsTxtread(path):
     return blob.download_as_string().decode()
 
 
-# In[224]:
+# In[354]:
 
 
 def gsTxtwrite(path, s):
@@ -598,7 +598,7 @@ def gsTxtwrite(path, s):
     return blob.upload_from_string(s)
 
 
-# In[225]:
+# In[355]:
 
 
 def gsImwrite(path, img):
@@ -607,7 +607,7 @@ def gsImwrite(path, img):
     blob.upload_from_string(encimg.tobytes())
 
 
-# In[226]:
+# In[356]:
 
 
 def gsImread(path):
@@ -616,7 +616,7 @@ def gsImread(path):
     return cv2.imdecode(raw, 1)[:, :, [2, 1, 0]]
 
 
-# In[227]:
+# In[357]:
 
 
 def gsPklWrite(path, obj):
@@ -624,7 +624,7 @@ def gsPklWrite(path, obj):
     return blob.upload_from_string(pickle.dumps(obj, protocol=4))
 
 
-# In[228]:
+# In[358]:
 
 
 def gsPklRead(path):
@@ -634,7 +634,7 @@ def gsPklRead(path):
 
 # # Pickle
 
-# In[229]:
+# In[359]:
 
 
 def pklwrite(path, obj):
@@ -647,7 +647,7 @@ def pklwrite(path, obj):
             return pickle.dump(obj, f, protocol=4)
 
 
-# In[230]:
+# In[360]:
 
 
 def pklread(path):
@@ -658,7 +658,7 @@ def pklread(path):
             return pickle.load(f)
 
 
-# In[231]:
+# In[361]:
 
 
 if is_testing():
@@ -671,7 +671,7 @@ if is_testing():
 
 # # Images
 
-# In[232]:
+# In[362]:
 
 
 def imread(path):
@@ -705,7 +705,7 @@ def impad(img, top=0, bottom=0, left=0, right=0, color=255):
     return np.pad(img, [(top, bottom), (left, right), (0, 0)], 'constant', constant_values=color)
 
 
-# In[233]:
+# In[363]:
 
 
 def imshow(array, scale=1):
@@ -720,7 +720,7 @@ def imshow(array, scale=1):
         cv2.waitKey()
 
 
-# In[234]:
+# In[364]:
 
 
 if is_testing():
@@ -728,14 +728,14 @@ if is_testing():
     imshow(img)
 
 
-# In[235]:
+# In[365]:
 
 
 if is_testing():
     imshow('http://via.placeholder.com/70.png')
 
 
-# In[236]:
+# In[366]:
 
 
 def imscaleNN(img, s):
@@ -745,7 +745,7 @@ def imscaleBic(img, s):
     return cv2.resize(img, None, fx=s, fy=s, interpolation=cv2.INTER_CUBIC)
 
 
-# In[237]:
+# In[367]:
 
 
 if is_testing():
@@ -764,7 +764,7 @@ if is_testing():
         imshow(out_large_interbic)
 
 
-# In[238]:
+# In[368]:
 
 
 def imRepeat(img, height, width):
@@ -778,7 +778,7 @@ def imRepeat(img, height, width):
     return img
 
 
-# In[239]:
+# In[369]:
 
 
 if is_testing():
@@ -786,33 +786,33 @@ if is_testing():
     imshow(imRepeat(img_random_color_3x5, 7, 11), scale=10)
 
 
-# In[240]:
+# In[370]:
 
 
 def imNewWhite(height, width):
     return np.ones((height, width, 3)).astype(np.uint8) * 255
 
 
-# In[241]:
+# In[371]:
 
 
 if is_testing(): imshow(imNewWhite(10, 500) - 30)
 
 
-# In[242]:
+# In[372]:
 
 
 def imNewBlack(height, width):
     return np.zeros((height, width, 3)).astype(np.uint8)
 
 
-# In[243]:
+# In[373]:
 
 
 if is_testing(): imshow(imNewBlack(10, 500))
 
 
-# In[244]:
+# In[374]:
 
 
 def imAddNoiseGauss(img, std):
@@ -824,7 +824,7 @@ def imAddNoiseGauss(img, std):
 if is_testing(): imshow(imAddNoiseGauss(imread('http://via.placeholder.com/150.png'), 10))
 
 
-# In[245]:
+# In[375]:
 
 
 def imJpgDegradation(img, quality):
@@ -837,7 +837,7 @@ def imJpgDegradation(img, quality):
 if is_testing(): imshow(imJpgDegradation(imread('http://via.placeholder.com/150.png'), 15))
 
 
-# In[246]:
+# In[376]:
 
 
 def imCropCenter(img, size):
@@ -852,35 +852,35 @@ def imCropCenter(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[247]:
+# In[377]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 10))
 
 
-# In[248]:
+# In[378]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 49))
 
 
-# In[249]:
+# In[379]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 50))
 
 
-# In[250]:
+# In[380]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 100))
 
 
-# In[251]:
+# In[381]:
 
 
 def imCropRandom(img, size):
@@ -895,7 +895,7 @@ def imCropRandom(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[252]:
+# In[382]:
 
 
 if is_testing(): 
@@ -903,7 +903,7 @@ if is_testing():
     imshow(imCropRandom(imread('http://via.placeholder.com/40.png'), 39))
 
 
-# In[253]:
+# In[383]:
 
 
 def imGallery(imgs, pad=0):
@@ -934,7 +934,7 @@ def imGallery(imgs, pad=0):
     return out
 
 
-# In[254]:
+# In[384]:
 
 
 if is_testing():
@@ -942,49 +942,49 @@ if is_testing():
     listOfDummyImagesBlackToWhite = [imNewBlack(10, 10) + 25 * i for i in range(10)]
 
 
-# In[255]:
+# In[385]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:1]))
 
 
-# In[256]:
+# In[386]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2]))
 
 
-# In[257]:
+# In[387]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2], pad=1))
 
 
-# In[258]:
+# In[388]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:5], pad=1))
 
 
-# In[259]:
+# In[389]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:9], pad=1))
 
 
-# In[260]:
+# In[390]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:10], pad=1))
 
 
-# In[261]:
+# In[391]:
 
 
 if is_testing():
@@ -994,14 +994,14 @@ if is_testing():
 
 # # Files
 
-# In[262]:
+# In[392]:
 
 
 def fiFindByWildcard(wildcard):
     return natsort.natsorted(glob.glob(wildcard, recursive=True))
 
 
-# In[263]:
+# In[393]:
 
 
 if is_testing():
@@ -1030,7 +1030,7 @@ if is_testing():
         imshow(imGallery(imgs))
 
 
-# In[264]:
+# In[394]:
 
 
 def fiRemove(path):
@@ -1058,7 +1058,7 @@ def fiAgeHours(path):
     return (time.time() - os.stat(path)[stat.ST_MTIME]) / 3600
 
 
-# In[265]:
+# In[395]:
 
 
 if is_testing():
@@ -1090,7 +1090,7 @@ if is_testing():
         print("files: " + "\n".join(fiFindByWildcard(os.path.join(d, "**", "*"))))
 
 
-# In[266]:
+# In[396]:
 
 
 def fiUnzip(zip_path, out_dir=None, remove=False):
@@ -1105,7 +1105,7 @@ def fiUnzip(zip_path, out_dir=None, remove=False):
         zip.extractall(out_dir)
 
 
-# In[267]:
+# In[397]:
 
 
 def fiJoin(*args):
@@ -1117,7 +1117,18 @@ if is_testing():
 
 # # Jupyter
 
-# In[294]:
+# In[425]:
+
+
+def jnSettings():
+    print('mkdir -p $(jupyter --data-dir)/nbextensions && cd $(jupyter --data-dir)/nbextensions && git clone https://github.com/lambdalisue/jupyter-vim-binding vim_binding && jupyter nbextension enable vim_binding/vim_binding && cd -')
+    print('pip3 install jupyter_contrib_nbextensions && jupyter contrib nbextension install --user && jupyter nbextension enable execute_time/ExecuteTime && jupyter nbextension enable code_prettify/code_prettify && jupyter nbextension enable cell_filter/cell_filter')
+
+if is_testing():
+    jnSettings()
+
+
+# In[398]:
 
 
 def jnNbFullWidth():
@@ -1131,7 +1142,7 @@ def jnPandasSettings():
     pd.set_option('display.max_colwidth', 100000)
 
 
-# In[269]:
+# In[399]:
 
 
 def jnImageRenderingPixelated():
@@ -1143,7 +1154,7 @@ def jnImageRenderingAuto():
     display(HTML('<style type = text/css> img { image-rendering: auto; } </style>'))
 
 
-# In[270]:
+# In[400]:
 
 
 def jnDefault():
@@ -1161,7 +1172,7 @@ if is_testing():
 
 
 
-# In[271]:
+# In[401]:
 
 
 def jnHtmlRow(strList, width=100):
@@ -1174,7 +1185,7 @@ if is_testing():
     
 
 
-# In[272]:
+# In[402]:
 
 
 def jnImgToHtmlB64(img):
@@ -1209,7 +1220,7 @@ def jnImageRow(imgs, names=None, width=100, external=False, title_img=None, titl
     display(HTML(html))
 
 
-# In[273]:
+# In[403]:
 
 
 if is_testing():
@@ -1217,7 +1228,7 @@ if is_testing():
    
 
 
-# In[274]:
+# In[404]:
 
 
 if is_testing():
@@ -1227,7 +1238,7 @@ if is_testing():
     jnImageRow(imgs, external=True, title='test')
 
 
-# In[275]:
+# In[405]:
 
 
 
@@ -1237,7 +1248,7 @@ if is_testing():
 
 # # Shell
 
-# In[276]:
+# In[406]:
 
 
 def shell(cmd):
@@ -1252,7 +1263,7 @@ def shell(cmd):
 
 # # GIT
 
-# In[277]:
+# In[407]:
 
 
 def gitGetHash():
@@ -1262,7 +1273,7 @@ if is_testing():
     print(gitGetHash())
 
 
-# In[278]:
+# In[408]:
 
 
 def gitGetBranch():
@@ -1272,7 +1283,7 @@ if is_testing():
     print(gitGetBranch())
 
 
-# In[279]:
+# In[409]:
 
 
 def gitGetMessage():
@@ -1282,7 +1293,7 @@ if is_testing():
     print(gitGetMessage())
 
 
-# In[280]:
+# In[410]:
 
 
 def gitGetAllFiles():
@@ -1292,7 +1303,7 @@ if is_testing():
     print(gitGetAllFiles())
 
 
-# In[281]:
+# In[411]:
 
 
 def gitListByTime(path=None):
@@ -1308,7 +1319,7 @@ if is_testing():
     print(gitListByTime()[-3:])
 
 
-# In[282]:
+# In[412]:
 
 
 def gitTime(path):
@@ -1319,7 +1330,7 @@ if is_testing():
     print(gitTime("__init__.py"))
 
 
-# In[283]:
+# In[413]:
 
 
 def gitTimeRaw(path):
@@ -1330,7 +1341,7 @@ if is_testing():
     print(gitTimeRaw("__init__.py"))
 
 
-# In[284]:
+# In[414]:
 
 
 def shellSortDirsBySize():
@@ -1342,14 +1353,14 @@ if is_testing():
 
 # # Package Files
 
-# In[285]:
+# In[415]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[286]:
+# In[416]:
 
 
 def shell(cmd):
@@ -1357,7 +1368,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[287]:
+# In[417]:
 
 
 if is_testing():
@@ -1389,7 +1400,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[288]:
+# In[418]:
 
 
 if is_testing():
@@ -1399,7 +1410,7 @@ description-file = README.md
 """
 
 
-# In[289]:
+# In[419]:
 
 
 if is_testing():
@@ -1422,14 +1433,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[290]:
+# In[420]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[291]:
+# In[421]:
 
 
 if is_testing():
@@ -1438,7 +1449,7 @@ if is_testing():
     
 
 
-# In[292]:
+# In[422]:
 
 
 if is_testing():
@@ -1449,7 +1460,7 @@ lx/__init__.py
 """
 
 
-# In[293]:
+# In[423]:
 
 
 if is_testing():
